@@ -2,7 +2,12 @@ from typing import Optional, Dict
 
 from robocorp_ls_core.client_base import LanguageServerClientBase
 from robocorp_ls_core.protocols import IIdMessageMatcher, IRobotFrameworkApiClient
-from robocorp_ls_core.lsp import TextDocumentTypedDict, ResponseTypedDict
+from robocorp_ls_core.lsp import (
+    TextDocumentTypedDict,
+    ResponseTypedDict,
+    PositionTypedDict,
+    CodeLensTypedDict,
+)
 from robocorp_ls_core.basic import implements
 
 
@@ -60,10 +65,7 @@ class RobotFrameworkApiClient(LanguageServerClientBase):
             }
         )
 
-    def get_version(self):
-        """
-        :return:
-        """
+    def get_version(self) -> str:
         if self._version is None:
             self._check_process_alive()
             msg_id = self.next_id()
@@ -111,6 +113,43 @@ class RobotFrameworkApiClient(LanguageServerClientBase):
             )
         )
 
+    def request_semantic_tokens_from_code_full(
+        self, prefix: str, full_code: str, indent: str
+    ) -> Optional[IIdMessageMatcher]:
+        """
+        :Note: async complete.
+        """
+        return self.request_async(
+            self._build_msg(
+                "semanticTokensFromCodeFull",
+                prefix=prefix,
+                full_code=full_code,
+                indent=indent,
+            )
+        )
+
+    def request_monaco_completions_from_code(
+        self,
+        prefix: str,
+        full_code: str,
+        position: PositionTypedDict,
+        uri: str,
+        indent: str,
+    ) -> Optional[IIdMessageMatcher]:
+        """
+        :Note: async complete.
+        """
+        return self.request_async(
+            self._build_msg(
+                "monacoCompletionsFromCodeFull",
+                prefix=prefix,
+                full_code=full_code,
+                position=position,
+                uri=uri,
+                indent=indent,
+            )
+        )
+
     def forward(self, method_name, params):
         self._check_process_alive()
         msg_id = self.next_id()
@@ -208,6 +247,14 @@ class RobotFrameworkApiClient(LanguageServerClientBase):
         """
         return self.request_async(self._build_msg("codeLens", doc_uri=doc_uri))
 
+    def request_resolve_code_lens(
+        self, code_lens: CodeLensTypedDict
+    ) -> Optional[IIdMessageMatcher]:
+        """
+        :Note: async complete.
+        """
+        return self.request_async(self._build_msg("resolveCodeLens", **code_lens))
+
     def request_document_symbol(self, doc_uri) -> Optional[IIdMessageMatcher]:
         """
         :Note: async complete.
