@@ -15,7 +15,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import functools
-import inspect
 import os
 import sys
 import threading
@@ -24,6 +23,7 @@ from contextlib import contextmanager
 from robocorp_ls_core.robotframework_log import get_logger
 from robocorp_ls_core.options import DEFAULT_TIMEOUT
 from typing import TypeVar, Any, Callable
+from robocorp_ls_core.jsonrpc.exceptions import JsonRpcRequestCancelled
 
 
 PARENT_PROCESS_WATCH_INTERVAL = 3  # 3 s
@@ -38,37 +38,6 @@ def as_str(s) -> str:
 log = get_logger(__name__)
 
 
-def debounce(interval_s, keyed_by=None):
-    """Debounce calls to this function until interval_s seconds have passed."""
-
-    def wrapper(func):
-        timers = {}
-        lock = threading.Lock()
-
-        @functools.wraps(func)
-        def debounced(*args, **kwargs):
-            call_args = inspect.getcallargs(func, *args, **kwargs)
-            key = call_args[keyed_by] if keyed_by else None
-
-            def run():
-                with lock:
-                    del timers[key]
-                return func(*args, **kwargs)
-
-            with lock:
-                old_timer = timers.get(key)
-                if old_timer:
-                    old_timer.cancel()
-
-                timer = threading.Timer(interval_s, run)
-                timers[key] = timer
-                timer.start()
-
-        return debounced
-
-    return wrapper
-
-
 def list_to_string(value):
     return ",".join(value) if isinstance(value, list) else value
 
@@ -175,35 +144,81 @@ else:
         return False
 
 
+def _popen(cmdline, **kwargs):
+    import subprocess
+
+    try:
+        return subprocess.Popen(cmdline, **kwargs)
+    except:
+        log.exception("Error running: %s", (" ".join(cmdline)))
+        return None
+
+
+def _call(cmdline, **kwargs):
+    import subprocess
+
+    try:
+        subprocess.check_call(cmdline, **kwargs)
+    except:
+        log.exception("Error running: %s", (" ".join(cmdline)))
+        return None
+
+
 def _kill_process_and_subprocess_linux(pid):
-    from robocorp_ls_core.subprocess_wrapper import subprocess
+    import subprocess
 
-    # Ask to stop forking
-    subprocess.call(
-        ["kill", "-stop", str(pid)],
+    initial_pid = pid
+
+    def list_children_and_stop_forking(ppid):
+        children_pids = []
+        _call(
+            ["kill", "-STOP", str(ppid)], stdout=subprocess.PIPE, stderr=subprocess.PIPE
+        )
+
+        list_popen = _popen(
+            ["pgrep", "-P", str(ppid)], stdout=subprocess.PIPE, stderr=subprocess.PIPE
+        )
+
+        if list_popen is not None:
+            stdout, _ = list_popen.communicate()
+            for line in stdout.splitlines():
+                line = line.decode("ascii").strip()
+                if line:
+                    pid = str(line)
+                    children_pids.append(pid)
+                    # Recursively get children.
+                    children_pids.extend(list_children_and_stop_forking(pid))
+        return children_pids
+
+    previously_found = set()
+
+    for _ in range(50):  # Try this at most 50 times before giving up.
+        children_pids = list_children_and_stop_forking(initial_pid)
+        found_new = False
+
+        for pid in children_pids:
+            if pid not in previously_found:
+                found_new = True
+                previously_found.add(pid)
+                _call(
+                    ["kill", "-KILL", str(pid)],
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.PIPE,
+                )
+
+        if not found_new:
+            break
+
+    # Now, finish the initial one.
+    _call(
+        ["kill", "-KILL", str(initial_pid)],
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE,
-        stdin=subprocess.PIPE,
-    )
-
-    process = subprocess.Popen(
-        ["pgrep", "-P", str(pid)],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-        stdin=subprocess.PIPE,
-    )
-    for pid in process.communicate()[0].splitlines():
-        _kill_process_and_subprocess_linux(pid.strip())
-
-    subprocess.call(
-        ["kill", "-KILL", str(pid)],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-        stdin=subprocess.PIPE,
     )
 
 
 def kill_process_and_subprocesses(pid):
+    log.info("Killing process and subprocesses of: %s", pid)
     from subprocess import CalledProcessError
 
     if sys.platform == "win32":
@@ -290,6 +305,9 @@ def log_and_silence_errors(logger, return_on_error=None):
         def new_func(*args, **kwargs):
             try:
                 return func(*args, **kwargs)
+            except JsonRpcRequestCancelled:
+                logger.info("Cancelled handling: %s", func)
+                raise  # Don't silence cancelled exceptions
             except:
                 logger.exception("Error calling: %s", func)
                 return return_on_error
